#--------------------------
# Leslie matrix simulation
# to run, select all, copy, paste at the prompt, and hit enter
#--------------------------

library(manipulate) # load library for manipulating the plot

# function for running Leslie matrix model
runLeslie = function(n,L,tf) {
  N = rep(0,tf) # for storing vector of total population size
  N[1] = sum(n) # initial total population size
  for(t in 1:(tf-1)) {# loop through years
    n = L%*%n # matrix multiplication - population in next year
    N[t+1] = sum(n) # total population size
  }
  return(N)
}

# Leslie matrix: example one to analyze
L = rbind(c(1/2, 1, 3/4), c(2/3, 0, 0), c(0, 1/3, 0))
tf = 8 # time steps to iterate
vt = 1:tf # vector of times

# find eigenvalues and eigenvectors of the Leslie matrix
ev = eigen(L) # extract eigenvalues and corresponding eigenvectors - enter ev$values and ev$vectors to see each
lev = which.max(Re(ev$values)) # find which one is leading eigenvalue take real part, then find index for the maximum
leval = ev$values[lev] # leading eigenvalue

# plot total population size over time - compare simulated values to how expect to grow at equilibrium (when at stable age distribution, N_t=N0*lambda^(t-1) for any t)
manipulate(
  matplot(vt,cbind(runLeslie(n0,L,tf),c(runLeslie(n0,L,tf)[1],leval*runLeslie(n0,L,tf)[-tf])),
          type=c("p","l"),pch=c(1,1), xlab="Time", ylab="Total population size"),
  n0=picker("All age 1"=c(2,0,0),"All age 2"=c(0,2,0),"All age 3"=c(0,0,2)))