#--------------------------
# to run, select each plot (code between the dashed lines) one at a time, copy, paste at the prompt, and hit enter
#--------------------------

#--------------------------
# Plot 1: bifurcation plot of Ricker model
# need to run this code first for the rest to work

library(manipulate) # load library for user-manipulated plots

# function to run Ricker model
ricker = function(r, K=100, N0=50, tf=100) { 
	N=matrix(0,nrow=tf,ncol=max(length(r),length(N0))) # set up empty matrix
	N[1,] = N0 # enter initial population size
	for(t in 1:(tf-1)) { # loop through each time step up to nsteps
		N[t+1,] <- N[t,]*exp(r*(1-N[t,]/K)) # calculate Ricker iteration
		}	
	return(N) # return N, vector of population size
	}

# plot
vr = seq(1.1, 4, by=0.01) # vector of values for r
tp = 100 # number of time points at end to extract for plotting
tf1 = 500 # final time
Nt = ricker(r=vr,tf=tf1) # run model
# plot results
matplot(matrix(rep(vr,tp),nrow=tp,byrow=TRUE),Nt[(tf1-tp+1):tf1,],
        col="black",pty="p",pch=1,xlab="Growth rate (r)",ylab="Population size (N) at t=400 through t=500") # plot as points
#--------------------------


#--------------------------
# Plot 2: plot Ricker for different values of r
tf2 = 50 # final time
manipulate(
  matplot(1:tf2,ricker(r=c(r1,r2,r3,r4),tf=tf2),
          type="l",lty=1,xlab="t",ylab="N_t",main="Ricker model with different values for r"),
  r1=slider(1,4,step=0.2,initial=1),
  r2=slider(1,4,step=0.2,initial=1),
  r3=slider(1,4,step=0.2,initial=1),
  r4=slider(1,4,step=0.2,initial=1))
#--------------------------

#--------------------------
# Plot 3: plot trajectories for two values of r that give chaos and are close to each other
manipulate(
  matplot(1:tf2,ricker(r=c(r1,r2),tf=tf2),
          type="l",xlab="Time (t)",ylab="Population size (Nt)",main=(paste("r1=",r1,", r2=",r2,sep=""))),
  r1=slider(3.5,4,step=0.01,initial=3.5),
  r2=slider(3.5,4,step=0.01,initial=3.5))
#--------------------------

#--------------------------
# Plot 4: plot N+tf vs. N_0 into the future
vN0 = 1:100 # vector of initial conditions
tfmax = 15 # maximum value for final time step
manipulate(
  plot(vN0,ricker(r=r,tf=tfmax,N0=vN0)[tf,],
       type="p",xlab="N_0",ylab=paste("N_",tf,sep=""),main=paste("r=",r,sep="")),
  r=slider(1,4,step=0.2,initial=1),
  tf=slider(2,tfmax,step=1,initial=2))
#--------------------------

